import{g as u,aT as s,r as m,R as e,E as g,F as n,c as p,G as E,K as f,a as o}from"./rpcWorker-CVTx5FIM.js";var v=s(),k=u(v);const C=({tracks:l,onClose:a})=>{const[r,i]=m.useState(`MultiWiggle ${Date.now()}`),c=l.every(t=>t.type==="QuantitativeTrack");return e.createElement(k,{open:!0,onClose:()=>{a(!1)},title:"Confirm multi-wiggle track create"},e.createElement(g,null,e.createElement(n,null,c?null:"Not every track looks like a QuantitativeTrack. This could have unexpected behavior, confirm if it looks ok.","Listing:"),e.createElement("ul",null,l.map(t=>e.createElement("li",{key:t.trackId},p.readConfObject(t,"name")," - ",t.type))),e.createElement(E,{value:r,onChange:t=>{i(t.target.value)},helperText:"Track name"}),e.createElement(n,null,"Confirm creation of track?")),e.createElement(f,null,e.createElement(o,{onClick:()=>{a(!1)},color:"primary"},"Cancel"),e.createElement(o,{onClick:()=>{a(!0,{name:r})},color:"primary",variant:"contained",autoFocus:!0},"Submit")))};export{C as default};
