import{aW as i,aX as o,aY as l,g as n}from"./rpcWorker-CVTx5FIM.js";var e={},r;function s(){if(r)return e;r=1;var a=i();Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0;var t=a(o()),u=l();return e.default=(0,t.default)((0,u.jsx)("path",{d:"M19 6.41 17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z"}),"Clear"),e}var v=s(),C=n(v);export{C};
