import{A as u,E as p,u as r,G as g,H as d,I as s}from"./index-Bm2SqMk3.js";import{a as S}from"./aborting-Bc8cczc3.js";function k(t){u(t,p(async()=>{try{if(!r.getContainingView(t).initialized)return;const{rpcManager:n}=r.getSession(t),{adapterConfig:a}=t,e=g.createStopToken();t.setSourcesLoading(e);const i=d.getRpcSessionId(t),c=await n.call(i,"MultiVariantGetSources",{sessionId:i,adapterConfig:a});s(t)&&t.setSources(c)}catch(o){!S.isAbortException(o)&&s(t)&&(console.error(o),r.getSession(t).notifyError(`${o}`,o))}},{delay:1e3}))}export{k as getMultiVariantSourcesAutorun};
