import{R as e,c as r,o,a,J as i}from"./index-Bm2SqMk3.js";const c=e.forwardRef(function({message:t},n){return e.createElement("div",{ref:n},e.isValidElement(t)?t:t?e.createElement(r.SanitizedHTML,{html:String(t)}):null)}),u=o(function({contents:l}){return l?e.createElement(a.Suspense,{fallback:null},e.createElement(i,null,e.createElement(c,{message:l}))):null});export{u as default};
