import{o as p,r as i,R as e,b as d,E as S,F as b,G as E,I as f,J as C,K as y,a as s}from"./rpcWorker-CVTx5FIM.js";const N=p(function(c){const{model:a,handleClose:n}=c,{featureHeightSetting:l,noSpacing:u}=a,[t,g]=i.useState(`${l}`),[r,h]=i.useState(u),m=t!==""&&!Number.isNaN(+t);return e.createElement(d.Dialog,{open:!0,onClose:n,title:"Set feature height"},e.createElement(S,null,e.createElement(b,null,"Adjust the feature height and whether there is any spacing between features. Setting feature height to 1 and removing spacing makes the display very compact."),e.createElement(E,{value:t,helperText:"Feature height",onChange:o=>{g(o.target.value)}}),e.createElement(f,{control:e.createElement(C,{checked:!!r,onChange:()=>{h(o=>!o)}}),label:"Remove spacing between features in y-direction?"}),e.createElement(y,null,e.createElement(s,{variant:"contained",color:"primary",type:"submit",autoFocus:!0,disabled:!m,onClick:()=>{a.setFeatureHeight(t!==""&&!Number.isNaN(+t)?+t:void 0),a.setNoSpacing(r),n()}},"Submit"),e.createElement(s,{variant:"contained",color:"secondary",onClick:()=>{n()}},"Cancel"))))});export{N as default};
