import{m as u,o as m,r as h,R as e,b as g,E as x,F as d,G as p,K as y,a as s}from"./rpcWorker-CVTx5FIM.js";const E=u()({root:{width:500}}),C=m(function(n){const{model:o,handleClose:a}=n,{classes:r}=E(),{maxHeight:l=""}=o,[t,c]=h.useState(`${l}`);return e.createElement(g.Dialog,{open:!0,onClose:a,title:"Set max height"},e.createElement(x,{className:r.root},e.createElement(d,null,'Set max height for the track. For example, you can increase this if the layout says "Max height reached"'),e.createElement(p,{value:t,autoFocus:!0,onChange:i=>{c(i.target.value)},placeholder:"Enter max height for layout"}),e.createElement(y,null,e.createElement(s,{variant:"contained",color:"primary",type:"submit",autoFocus:!0,onClick:()=>{o.setMaxHeight(t!==""&&!Number.isNaN(+t)?+t:void 0),a()}},"Submit"),e.createElement(s,{variant:"contained",color:"secondary",onClick:()=>{a()}},"Cancel"))))});export{C as default};
