import{a9 as g,aa as u,u as s,s as p,V as S,ab as r}from"./rpcWorker-CVTx5FIM.js";import{a as d}from"./aborting-9Hf1R5vU.js";function E(o){g(o,u(async()=>{try{const t=s.getContainingView(o);if(!t.initialized)return;const{rpcManager:n}=s.getSession(o),{adapterConfig:a}=o,e=p.createStopToken();o.setSourcesLoading(e);const i=S.getRpcSessionId(o),c=await n.call(i,"MultiWiggleGetSources",{regions:t.staticBlocks.contentBlocks,sessionId:i,adapterConfig:a});r(o)&&o.setSources(c)}catch(t){!d.isAbortException(t)&&r(o)&&(console.error(t),s.getSession(o).notifyError(`${t}`,t))}}))}export{E as getMultiWiggleSourcesAutorun};
