import{R as e,b as r,E as i,F as o,K as l,a as n}from"./rpcWorker-CVTx5FIM.js";function c({onClose:t,plugin:a}){return e.createElement(r.Dialog,{open:!0,onClose:()=>{t()},title:`Remove ${a}`},e.createElement(i,null,e.createElement(o,null,"Please confirm that you want to remove ",a,"."),e.createElement(o,{color:"error"},"Note: if any resources in this session still use this plugin, it may cause your session to crash")),e.createElement(l,null,e.createElement(n,{variant:"contained",color:"primary",onClick:()=>{window.setTimeout(()=>{t(a)},500)}},"Confirm"),e.createElement(n,{variant:"contained",color:"secondary",onClick:()=>{t()}},"Cancel")))}export{c as default};
