import{o as m,r as s,R as e,b as r,E as g,F as u,G as l,K as p,a as c}from"./rpcWorker-CVTx5FIM.js";const h=m(function({model:t,handleClose:n}){const[a,d]=s.useState(`${t.windowSizeSetting}`),[i,w]=s.useState(`${t.windowDeltaSetting}`);return e.createElement(r.Dialog,{open:!0,onClose:n,title:"Edit GC content params"},e.createElement(g,null,e.createElement(u,null,"GC content is calculated in a particular sliding window of size N, and then the sliding window moves (steps) some number of bases M forward. Note that small step sizes can result in high CPU over large areas, and it is not recommended to make the step size larger than the window size as then the sliding window will miss contents."),+i>+a?e.createElement(r.ErrorMessage,{error:"It is not recommended to make the step size larger than the window size"}):null,e.createElement(l,{label:"Size of sliding window (bp)",value:a,onChange:o=>{d(o.target.value)}}),e.createElement(l,{label:"Step size of sliding window (bp)",value:i,onChange:o=>{w(o.target.value)}}),e.createElement(p,null,e.createElement(c,{variant:"contained",onClick:()=>{t.setGCContentParams({windowSize:+a,windowDelta:+i}),n()}},"Submit"),e.createElement(c,{variant:"contained",color:"secondary",onClick:()=>{n()}},"Cancel"))))});export{h as default};
