import{X as s,u as c,R as t,Y as i}from"./rpcWorker-CVTx5FIM.js";async function g(e,a,n){await s(()=>!!e.stats&&!!e.regionCannotBeRenderedText);const{needsScalebar:r,stats:o}=e,{offsetPx:l}=c.getContainingView(e);return t.createElement(t.Fragment,null,t.createElement("g",null,await n(a)),r&&o?t.createElement("g",{transform:`translate(${Math.max(-l,0)})`},t.createElement(i,{model:e,orientation:"left"})):null)}export{g as renderSvg};
