import{o as c,R as e,aa as l,ab as r,ac as a,u as n}from"./index-Bm2SqMk3.js";import{a as s}from"./ErrorMessageStackTraceDialog-DIivVudC.js";import{R as i,a as m}from"./Report-sRX8wyHH.js";const k=c(function({model:t}){return e.createElement(l,{message:`${t.error}`,severity:"error",action:e.createElement(e.Fragment,null,e.createElement(r,{title:"Reload track"},e.createElement(a,{"data-testid":"reload_button",onClick:()=>{t.reload()}},e.createElement(i,null))),e.createElement(r,{title:"Show stack trace"},e.createElement(a,{onClick:()=>{n.getSession(t).queueDialog(o=>[s,{onClose:o,error:t.error}])}},e.createElement(m,null))))})});export{k as default};
