import{u as n,R as t}from"./rpcWorker-CVTx5FIM.js";import{A as a}from"./Arcs-BHxqO6AV.js";async function g(e,l){await n.when(()=>!e.loading);const r=n.getContainingView(e).dynamicBlocks.totalWidthPx,c=e.height,i=`arc-${e.id}`;return t.createElement(t.Fragment,null,t.createElement("defs",null,t.createElement("clipPath",{id:i},t.createElement("rect",{x:0,y:0,width:r,height:c}))),t.createElement("g",{clipPath:`url(#${i})`},t.createElement(a,{model:e,exportSVG:!0})))}export{g as renderArcSvg};
