import{o as i,a as g,R as e,c as m,D as p,T as r,d,e as u,B as n}from"./index-Bm2SqMk3.js";const f=i(function({model:l,handleClose:a}){const[t,c]=g.useState(""),o=/^[A-Za-z][A-Za-z0-9]$/.exec(t);return e.createElement(m.Dialog,{open:!0,onClose:a,title:"Color by tag"},e.createElement(p,{style:{overflowX:"hidden"}},e.createElement(r,null,"Enter tag to color by: "),e.createElement(r,{color:"textSecondary"},"Examples: XS or TS for RNA-seq inferred read strand, ts (lower-case) for minimap2 read strand, HP for haplotype, RG for read group, etc."),e.createElement(d,{value:t,onChange:s=>{c(s.target.value)},placeholder:"Enter tag name",error:t.length===2&&!o,helperText:t.length===2&&!o?"Not a valid tag":"",autoComplete:"off",slotProps:{htmlInput:{maxLength:2}}}),e.createElement(u,null,e.createElement(n,{variant:"contained",color:"primary",onClick:()=>{l.setColorScheme({type:"tag",tag:t}),a()},disabled:!o},"Submit"),e.createElement(n,{variant:"contained",color:"secondary",onClick:a},"Cancel"))))});export{f as default};
