import{a9 as u,aa as p,u as r,s as g,V as d,ab as i}from"./rpcWorker-CVTx5FIM.js";import{a as S}from"./aborting-9Hf1R5vU.js";function k(t){u(t,p(async()=>{try{if(!r.getContainingView(t).initialized)return;const{rpcManager:s}=r.getSession(t),{adapterConfig:n}=t,e=g.createStopToken();t.setSourcesLoading(e);const a=d.getRpcSessionId(t),c=await s.call(a,"MultiVariantGetSources",{sessionId:a,adapterConfig:n});i(t)&&t.setSources(c)}catch(o){!S.isAbortException(o)&&i(t)&&(console.error(o),r.getSession(t).notifyError(`${o}`,o))}},{delay:1e3}))}export{k as getMultiVariantSourcesAutorun};
