const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/BreakendSingleLevelOptionDialog-BmZ-GTMg.js","assets/index-Bm2SqMk3.js","assets/index-B32Lr0K5.css"])))=>i.map(i=>d[i]);
import{u,R as e,a as d,_ as w,T as E,L as m}from"./index-Bm2SqMk3.js";import{B as _}from"./BaseCard-BEWjgl8a.js";const f=d.lazy(()=>w(()=>import("./BreakendSingleLevelOptionDialog-BmZ-GTMg.js").then(n=>n.b),__vite__mapDeps([0,1,2]))),g=d.lazy(()=>w(()=>import("./BreakendSingleLevelOptionDialog-BmZ-GTMg.js").then(n=>n.c),__vite__mapDeps([0,1,2])));function k({locStrings:n,model:t}){const r=u.getSession(t);return e.createElement("div",null,e.createElement(E,null,"Navigate to breakend endpoint in linear view:"),e.createElement("ul",null,n.map((i,s)=>e.createElement("li",{key:`${i}-${s}`},i," ",e.createElement(m,{href:"#",onClick:o=>{var a;o.preventDefault();const{view:l}=t;try{if(l)(a=l.navToLocString)===null||a===void 0||a.call(l,i);else throw new Error("No view associated with this feature detail panel anymore")}catch(c){console.error(c),r.notify(`${c}`)}}},"(LGV)")))))}function y({locStrings:n,model:t,feature:r}){var i,s;const o=u.getSession(t),a=new u.SimpleFeature(r),l=(s=(i=t.view)===null||i===void 0?void 0:i.displayedRegions[0])===null||s===void 0?void 0:s.assemblyName;return e.createElement("div",null,e.createElement(E,null,"Launch split view"),e.createElement("ul",null,n.map(c=>e.createElement("li",{key:JSON.stringify(c)},`${r.refName}:${r.start} // ${c}`," ",e.createElement(m,{href:"#",onClick:v=>{v.preventDefault(),o.queueDialog(p=>[f,{handleClose:p,session:o,feature:a,stableViewId:`${t.id}_${l}_breakpointsplitview_multilevel`,view:t.view,assemblyName:l}])}},"(top/bottom)")," ",e.createElement(m,{href:"#",onClick:v=>{v.preventDefault(),o.queueDialog(p=>[g,{handleClose:p,session:o,feature:a,stableViewId:`${t.id}_${l}_breakpointsplitview_singlelevel`,view:t.view,assemblyName:l}])}},"(single row)")))))}function S(n){const{model:t,locStrings:r,feature:i}=n,s=u.getSession(t),{pluginManager:o}=u.getEnv(s);let a=!1;try{a=!!o.getViewType("BreakpointSplitView")}catch{}return e.createElement(_,{...n,title:"Breakends"},e.createElement(k,{model:t,locStrings:r}),a?e.createElement(y,{model:t,locStrings:r,feature:i}):null)}export{S as default};
