import{m as x,o as M,r as i,u as b,R as e,Q as S,S as k,U as L,b as w}from"./rpcWorker-CVTx5FIM.js";const B=x()({cursor:{pointerEvents:"none"}}),C=M(function(r){const{model:l}=r,{classes:f}=B(),{height:c,sources:u,rowHeight:y,scrollTop:a}=l,m=i.useRef(null),[n,d]=i.useState(),[p,v]=i.useState(),{width:E}=b.getContainingView(l);return e.createElement("div",{ref:m,onMouseMove:t=>{var s;const o=(s=m.current)===null||s===void 0?void 0:s.getBoundingClientRect(),g=(o==null?void 0:o.top)||0,h=(o==null?void 0:o.left)||0;d(t.clientY-g),v(t.clientX-h)},onMouseLeave:()=>{d(void 0),v(void 0)}},e.createElement(S,{...r}),e.createElement(k,{model:l}),n&&u?e.createElement("div",{style:{position:"relative"}},e.createElement("svg",{className:f.cursor,width:E,height:c,style:{position:"absolute",top:a}},e.createElement("line",{x1:0,x2:E,y1:n-a,y2:n-a,stroke:"black"}),e.createElement("line",{x1:p,x2:p,y1:0,y2:c,stroke:"black"})),e.createElement(L,null,e.createElement(w.SanitizedHTML,{html:Object.entries(u[Math.floor(n/y)]||{}).filter(([t])=>t!=="color").map(([t,s])=>`${t}:${s}`).join(`
`)}))):null)});export{C as default};
