import{f as N}from"./index-Bm2SqMk3.js";import{r as R}from"./core-CVi8jHm4.js";function T(p,g){for(var c=0;c<g.length;c++){const t=g[c];if(typeof t!="string"&&!Array.isArray(t)){for(const n in t)if(n!=="default"&&!(n in p)){const h=Object.getOwnPropertyDescriptor(t,n);h&&Object.defineProperty(p,n,h.get?h:{enumerable:!0,get:()=>t[n]})}}}return Object.freeze(Object.defineProperty(p,Symbol.toStringTag,{value:"Module"}))}var A={exports:{}},K=A.exports,q;function L(){return q||(q=1,function(p,g){(function(c,t){p.exports=t(R())})(K,function(c){return function(t){var n=c,h=n.lib,O=h.WordArray,H=h.Hasher,C=n.algo,w=[],B=[];(function(){function i(o){for(var u=t.sqrt(o),l=2;l<=u;l++)if(!(o%l))return!1;return!0}function v(o){return(o-(o|0))*4294967296|0}for(var r=2,e=0;e<64;)i(r)&&(e<8&&(w[e]=v(t.pow(r,1/2))),B[e]=v(t.pow(r,1/3)),e++),r++})();var f=[],P=C.SHA256=H.extend({_doReset:function(){this._hash=new O.init(w.slice(0))},_doProcessBlock:function(i,v){for(var r=this._hash.words,e=r[0],o=r[1],u=r[2],l=r[3],s=r[4],y=r[5],b=r[6],S=r[7],a=0;a<64;a++){if(a<16)f[a]=i[v+a]|0;else{var d=f[a-15],W=(d<<25|d>>>7)^(d<<14|d>>>18)^d>>>3,_=f[a-2],D=(_<<15|_>>>17)^(_<<13|_>>>19)^_>>>10;f[a]=W+f[a-7]+D+f[a-16]}var F=s&y^~s&b,$=e&o^e&u^o&u,k=(e<<30|e>>>2)^(e<<19|e>>>13)^(e<<10|e>>>22),z=(s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25),j=S+z+F+B[a]+f[a],E=k+$;S=b,b=y,y=s,s=l+j|0,l=u,u=o,o=e,e=j+E|0}r[0]=r[0]+e|0,r[1]=r[1]+o|0,r[2]=r[2]+u|0,r[3]=r[3]+l|0,r[4]=r[4]+s|0,r[5]=r[5]+y|0,r[6]=r[6]+b|0,r[7]=r[7]+S|0},_doFinalize:function(){var i=this._data,v=i.words,r=this._nDataBytes*8,e=i.sigBytes*8;return v[e>>>5]|=128<<24-e%32,v[(e+64>>>9<<4)+14]=t.floor(r/4294967296),v[(e+64>>>9<<4)+15]=r,i.sigBytes=v.length*4,this._process(),this._hash},clone:function(){var i=H.clone.call(this);return i._hash=this._hash.clone(),i}});n.SHA256=H._createHelper(P),n.HmacSHA256=H._createHmacHelper(P)}(Math),c.SHA256})}(A)),A.exports}var x=L();const G=N(x),U=T({__proto__:null,default:G},[x]);export{U as s};
