import{m,o as u,r as h,R as e,b as x,E as g,F as E,G as p,K as y,a as s}from"./rpcWorker-CVTx5FIM.js";const d=m()({root:{width:500}}),v=u(function({model:o,handleClose:a}){const{classes:n}=d(),{maxHeight:c=""}=o,[t,l]=h.useState(`${c}`),r=t!==""&&!Number.isNaN(+t);return e.createElement(x.Dialog,{open:!0,onClose:a,title:"Set max height"},e.createElement(g,{className:n.root},e.createElement(E,null,'Set max height for the track. For example, you can increase this if the layout says "Max height reached"'),e.createElement(p,{value:t,onChange:i=>{l(i.target.value)},placeholder:"Enter max score"}),r?null:e.createElement("div",{style:{color:"red"}},"Invalid number")),e.createElement(y,null,e.createElement(s,{variant:"contained",color:"primary",type:"submit",autoFocus:!0,disabled:!r,onClick:()=>{o.setMaxHeight(+t),a()}},"Submit"),e.createElement(s,{variant:"contained",color:"secondary",onClick:()=>{a()}},"Cancel")))});export{v as default};
