import{m as n,o as s,R as e,P as o,T as r,B as l,a3 as i}from"./index-Bm2SqMk3.js";const p=n()(t=>({note:{textAlign:"center",paddingTop:t.spacing(1),paddingBottom:t.spacing(1)},top:{zIndex:1e3}})),u=s(function({model:t}){const{classes:a}=p(),{hideNoTracksActive:c}=t;return e.createElement(o,{className:a.note},c?e.createElement("div",{style:{height:"48px"}}):e.createElement(e.Fragment,null,e.createElement(r,null,"No tracks active."),e.createElement(l,{variant:"contained",color:"primary",onClick:()=>t.activateTrackSelector(),className:a.top,startIcon:e.createElement(i.TrackSelector,null)},"Open track selector")))});export{u as default};
