import{q as M,v as m,w as x,x as h,y}from"./rpcWorker-CVTx5FIM.js";function v(o,p){const a=o.get("strand"),l=o.get("seq"),g=M(o,"MM","Mm")||"",P=p||m(o.get("CIGAR"));if(l){const f=x(g,l,a),r=h(o),t=[];let b=0;for(const{type:c,positions:e}of f){for(const{ref:n,idx:d}of y(P,e)){const s=(r==null?void 0:r[b+(a===-1?e.length-1-d:d)])||0;if(!t[n])t[n]={type:c,prob:s,allProbs:[s]};else{const i=t[n];t[n]={allProbs:[...i.allProbs,s],prob:Math.max(i.prob,s),type:i.prob>s?i.type:c}}}b+=e.length}return t}}export{v as g};
