import{o as s,u as i,r as h,R as n}from"./rpcWorker-CVTx5FIM.js";import{B as l}from"./BaseDisplayComponent-hiDF5ISs.js";const u=s(function({model:t}){const o=i.getContainingView(t),e=Math.round(o.dynamicBlocks.totalWidthPx),a=t.height,r=h.useCallback(c=>{t.setRef(c)},[t,e,a]);return n.createElement("canvas",{"data-testid":"arc-canvas",ref:r,style:{width:e,height:a,position:"absolute"},width:e*2,height:a*2})}),d=s(function({model:t}){return n.createElement(l,{model:t},n.createElement(u,{model:t}))});export{d as default};
