import{aV as r,a9 as s}from"./index-Bm2SqMk3.js";import{I as p,a as f}from"./IndexedFastaAdapter-BDiF1jjP.js";import"./index-6rN3ss-L.js";import"./QuickLRU-BERSBA88.js";import"./rxjs-DT7GVwt0.js";class d extends p{constructor({fasta:a,path:t,fai:o,faiPath:n,gzi:e,gziPath:i}){super({fasta:a,path:t,fai:o,faiPath:n}),a&&e?this.fasta=new r({filehandle:a,gziFilehandle:e}):t&&i&&(this.fasta=new r({path:t,gziPath:i}))}}class m extends f{async setupPre(){const a=this.getConf("fastaLocation"),t=this.getConf("faiLocation"),o=this.getConf("gziLocation"),n={fasta:s.openLocation(a,this.pluginManager),fai:s.openLocation(t,this.pluginManager),gzi:s.openLocation(o,this.pluginManager)};return{fasta:new d(n)}}}export{m as default};
