import{c as a}from"./rpcWorker-CVTx5FIM.js";import{B as f}from"./index-P3rx-5SH.js";import{makeFeatures as n}from"./FromConfigAdapter-BH4Yj5E4.js";import"./rxjs-Dgg09m9e.js";import"./simpleFeature-DW3q5zmr.js";class g extends f.BaseAdapter{constructor(t,r,s){super(t,r,s);const e=a.readConfObject(t,"features");this.features=n(e)}async getRegions(){const t=[];for(const[r,s]of this.features){let e;for(const o of s)e&&e.end>=o.get("start")&&e.start<=o.get("end")?e.end=o.get("end"):(e&&t.push(e),e={refName:r,start:o.get("start"),end:o.get("end")});e&&t.push(e)}return t.sort((r,s)=>r.refName.localeCompare(s.refName)),t}freeResources(){}}export{g as default};
