import{a5 as a,a6 as s}from"./rpcWorker-CVTx5FIM.js";const e={color_fwd_strand_not_proper:"#ECC8C8",color_rev_strand_not_proper:"#BEBED8",color_fwd_strand:"#EC8B8B",color_rev_strand:"#8F8FD8",color_fwd_missing_mate:"#D11919",color_rev_missing_mate:"#1919D1",color_fwd_diff_chr:"#000",color_rev_diff_chr:"#969696",color_pair_lr:"#c8c8c8",color_pair_rr:"navy",color_pair_rl:"teal",color_pair_ll:"green",color_nostrand:"#c8c8c8",color_interchrom:"purple",color_longinsert:"red",color_shortinsert:"pink",color_unknown:"grey"},l={color_fwd_strand_not_proper:"#CA6767",color_rev_strand_not_proper:"#7272AA",color_fwd_strand:"#DC2A2A",color_rev_strand:"#4141BA",color_fwd_missing_mate:"#921111",color_rev_missing_mate:"#111192",color_fwd_diff_chr:"#000000",color_rev_diff_chr:"#696969",color_pair_lr:"#8C8C8C",color_pair_rr:"#00005A",color_pair_rl:"#005A5A",color_pair_ll:"#005A00",color_nostrand:"#8C8C8C",color_interchrom:"#5A005A",color_longinsert:"#B30000",color_shortinsert:"#FF3A5C",color_unknown:"grey"};function d(o,_,r){const n=o.refName===_.refName,t=Math.abs(o.tlen||0);return n&&t>((r==null?void 0:r.upper)||0)?[e.color_longinsert,l.color_longinsert]:n&&t<((r==null?void 0:r.lower)||0)?[e.color_shortinsert,l.color_shortinsert]:n?void 0:[e.color_interchrom,l.color_interchrom]}const c=[e.color_unknown,e.color_unknown];function p(o,_,r){return i(o)||d(o,_,r)||c}function i(o){const r=a.fr[o.pair_orientation||""],n=s[r];return r==="LR"?void 0:[e[n],l[n]]}function u(o){return i(o)||c}export{u as a,d as b,e as f,p as g,l as s};
