import{o as r,R as e,c as u,D as m,aq as s,e as D,B as a}from"./index-Bm2SqMk3.js";const g=r(function({deleteDialogDetails:l,session:o,handleClose:t}){const{connectionConf:c,name:i}=l;return e.createElement(u.Dialog,{open:!0,title:`Delete connection "${i}"`,onClose:t},e.createElement(m,null,e.createElement(s,null,"Are you sure you want to delete this connection?")),e.createElement(D,null,e.createElement(a,{onClick:()=>{t()},color:"primary"},"Cancel"),e.createElement(a,{variant:"contained",color:"primary",onClick:()=>{var n;(n=o.deleteConnection)===null||n===void 0||n.call(o,c),t()}},"OK")))});export{g as default};
