import{aR as r,i as n}from"./rpcWorker-CVTx5FIM.js";import{I as c,a as f}from"./IndexedFastaAdapter-1FV7OuWI.js";import"./AbortablePromiseCache-xs5eyOH3.js";import"./index-P3rx-5SH.js";import"./QuickLRU-Cm0slBPC.js";import"./rxjs-Dgg09m9e.js";class d extends c{constructor({fasta:a,path:t,fai:o,faiPath:i,gzi:s,gziPath:e}){super({fasta:a,path:t,fai:o,faiPath:i}),a&&s?this.fasta=new r({filehandle:a,gziFilehandle:s}):t&&e&&(this.fasta=new r({path:t,gziPath:e}))}}class x extends f{async setupPre(){const a=this.getConf("fastaLocation"),t=this.getConf("faiLocation"),o=this.getConf("gziLocation"),i={fasta:n.openLocation(a,this.pluginManager),fai:n.openLocation(t,this.pluginManager),gzi:n.openLocation(o,this.pluginManager)};return{fasta:new d(i)}}}export{x as default};
