import{R as e,c as r,D as i,T as a,e as l,B as n}from"./index-Bm2SqMk3.js";function c({onClose:t,plugin:o}){return e.createElement(r.Dialog,{open:!0,onClose:()=>{t()},title:`Remove ${o}`},e.createElement(i,null,e.createElement(a,null,"Please confirm that you want to remove ",o,"."),e.createElement(a,{color:"error"},"Note: if any resources in this session still use this plugin, it may cause your session to crash")),e.createElement(l,null,e.createElement(n,{variant:"contained",color:"primary",onClick:()=>{window.setTimeout(()=>{t(o)},500)}},"Confirm"),e.createElement(n,{variant:"contained",color:"secondary",onClick:()=>{t()}},"Cancel")))}export{c as default};
