import{m as i,o as u,a as m,R as e,a0 as f,D as g,T as p,d as y,e as E,B as o}from"./index-Bm2SqMk3.js";const F=i()({root:{width:500}}),S=u(function({model:r,handleClose:t}){const{mafFilter:n=""}=r,{classes:l}=F(),[a,s]=m.useState(`${n}`);return e.createElement(f,{open:!0,onClose:t,title:"Set minor allele frequency (MAF)"},e.createElement(g,{className:l.root},e.createElement(p,null,"Set minor allele frequency cutoff track. This will filter out rare variants that might not contribute to meaningful large scale patterns"),e.createElement(y,{value:a,autoFocus:!0,placeholder:"Enter MAF",onChange:c=>{s(c.target.value)}}),e.createElement(E,null,e.createElement(o,{variant:"contained",color:"primary",type:"submit",autoFocus:!0,onClick:()=>{Number.isNaN(+a)||r.setMafFilter(+a),t()}},"Submit"),e.createElement(o,{variant:"contained",color:"secondary",onClick:()=>{t()}},"Cancel"))))});export{S as default};
