const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/canvas2svg-DwO0L0JY.js","assets/index-Bm2SqMk3.js","assets/index-B32Lr0K5.css"])))=>i.map(i=>d[i]);
import{u as d,R as e,_ as h}from"./index-Bm2SqMk3.js";function g(t){return`arc-clip-${typeof jest>"u"?t:"jest"}`}async function p(t,c,o){const n=d.getContainingView(t).dynamicBlocks.totalWidthPx,i=t.height;if(c.rasterizeLayers){const a=document.createElement("canvas");a.width=n*2,a.height=i*2;const r=a.getContext("2d");return r?(r.scale(2,2),o(t,r,n,i),e.createElement("image",{width:n,height:i,xlinkHref:a.toDataURL("image/png")})):void 0}else{const a=await h(()=>import("./canvas2svg-DwO0L0JY.js").then(l=>l.c),__vite__mapDeps([0,1,2])),r=new a.default(n,i);o(t,r,n,i);const s=g(t.id);return e.createElement(e.Fragment,null,e.createElement("defs",null,e.createElement("clipPath",{id:s},e.createElement("rect",{x:0,y:0,width:n,height:i}))),e.createElement("g",{dangerouslySetInnerHTML:{__html:r.getSvg().innerHTML},clipPath:`url(#${s})`}))}}export{p as renderSvg};
