import{g as u,D as i}from"./rpcWorker-CVTx5FIM.js";function f(o,n){return n.forEach(function(r){r&&typeof r!="string"&&!Array.isArray(r)&&Object.keys(r).forEach(function(t){if(t!=="default"&&!(t in o)){var e=Object.getOwnPropertyDescriptor(r,t);Object.defineProperty(o,t,e.get?e:{enumerable:!0,get:function(){return r[t]}})}})}),Object.freeze(o)}var a=i(),m=u(a),c=f({__proto__:null,default:m},[a]);export{c as R};
