const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/ErrorMessageStackTraceDialog-DIivVudC.js","assets/index-Bm2SqMk3.js","assets/index-B32Lr0K5.css"])))=>i.map(i=>d[i]);
import{a as i,_ as u,m as g,o as r,R as t,aa as m,ab as o,ac as s,u as d,c as p}from"./index-Bm2SqMk3.js";import{A as E}from"./Arcs-BDg83GWX.js";import{R as k,a as b}from"./Report-sRX8wyHH.js";const f=i.lazy(()=>u(()=>import("./ErrorMessageStackTraceDialog-DIivVudC.js").then(e=>e.E),__vite__mapDeps([0,1,2]))),x=g()(e=>({loading:{backgroundColor:e.palette.background.default,backgroundImage:`repeating-linear-gradient(45deg, transparent, transparent 5px, ${e.palette.action.disabledBackground} 5px, ${e.palette.action.disabledBackground} 10px)`,position:"absolute",bottom:0,height:50,width:300,right:0,pointerEvents:"none",textAlign:"center"}})),R=r(function({model:e,children:a}){const{error:n,regionTooLarge:l}=e;return n?t.createElement(m,{message:`${n}`,severity:"error",action:t.createElement(t.Fragment,null,t.createElement(o,{title:"Reload"},t.createElement(s,{"data-testid":"reload_button",onClick:()=>{e.reload()}},t.createElement(k,null))),t.createElement(o,{title:"Show stack trace"},t.createElement(s,{onClick:()=>{d.getSession(e).queueDialog(c=>[f,{onClose:c,error:e.error}])}},t.createElement(b,null))))}):l?e.regionCannotBeRendered():t.createElement(_,{model:e},a)}),_=r(function({model:e,children:a}){const{loading:n}=e;return t.createElement("div",null,a,n?t.createElement(v,{model:e}):null)}),v=r(function({model:e}){const{classes:a}=x(),{message:n}=e;return t.createElement("div",{className:a.loading},t.createElement(p.LoadingEllipses,{message:n}))}),D=r(function({model:e,exportSVG:a}){return t.createElement(R,{model:e},t.createElement(E,{model:e,exportSVG:a}))});export{D as default};
