import{o as m,R as e,b as u,E as C,al as a,am as E,an as g,K as p,a as c}from"./rpcWorker-CVTx5FIM.js";const D=m(function({modalInfo:i={},onClose:n}){const{name:r,dereferenceTypeCount:l,safelyBreakConnection:t}=i;return e.createElement(u.Dialog,{open:!0,maxWidth:"lg",title:`Close connection "${r}"`,onClose:n},e.createElement(C,null,l?e.createElement(e.Fragment,null,e.createElement(a,null,"Closing this connection will close:"),e.createElement(E,null,Object.entries(l).map(([o,s])=>e.createElement(g,{key:o},`${s} ${o}`)))):null,e.createElement(a,null,"Are you sure you want to close this connection?")),e.createElement(p,null,e.createElement(c,{onClick:()=>{n()},color:"primary"},"Cancel"),e.createElement(c,{variant:"contained",onClick:()=>{t==null||t(),n()},color:"primary"},"OK")))});export{D as default};
