import{aV as m}from"./rpcWorker-CVTx5FIM.js";import{c as W}from"./_commonjs-dynamic-modules-TDtrdbi3.js";import{r as L}from"./___vite-browser-external_commonjs-proxy-DG_c_Omb.js";var p={exports:{}},U=p.exports,S;function P(){return S||(S=1,function(C,$){(function(y,f){C.exports=f()})(U,function(){var y=y||function(f,b){var s;if(typeof window<"u"&&window.crypto&&(s=window.crypto),typeof self<"u"&&self.crypto&&(s=self.crypto),typeof globalThis<"u"&&globalThis.crypto&&(s=globalThis.crypto),!s&&typeof window<"u"&&window.msCrypto&&(s=window.msCrypto),!s&&typeof m<"u"&&m.crypto&&(s=m.crypto),!s&&typeof W=="function")try{s=L}catch{}var R=function(){if(s){if(typeof s.getRandomValues=="function")try{return s.getRandomValues(new Uint32Array(1))[0]}catch{}if(typeof s.randomBytes=="function")try{return s.randomBytes(4).readInt32LE()}catch{}}throw new Error("Native crypto module could not be used to get secure random number.")},z=Object.create||function(){function t(){}return function(r){var n;return t.prototype=r,n=new t,t.prototype=null,n}}(),h={},d=h.lib={},c=d.Base=function(){return{extend:function(t){var r=z(this);return t&&r.mixIn(t),(!r.hasOwnProperty("init")||this.init===r.init)&&(r.init=function(){r.$super.init.apply(this,arguments)}),r.init.prototype=r,r.$super=this,r},create:function(){var t=this.extend();return t.init.apply(t,arguments),t},init:function(){},mixIn:function(t){for(var r in t)t.hasOwnProperty(r)&&(this[r]=t[r]);t.hasOwnProperty("toString")&&(this.toString=t.toString)},clone:function(){return this.init.prototype.extend(this)}}}(),u=d.WordArray=c.extend({init:function(t,r){t=this.words=t||[],r!=b?this.sigBytes=r:this.sigBytes=t.length*4},toString:function(t){return(t||k).stringify(this)},concat:function(t){var r=this.words,n=t.words,e=this.sigBytes,i=t.sigBytes;if(this.clamp(),e%4)for(var o=0;o<i;o++){var g=n[o>>>2]>>>24-o%4*8&255;r[e+o>>>2]|=g<<24-(e+o)%4*8}else for(var a=0;a<i;a+=4)r[e+a>>>2]=n[a>>>2];return this.sigBytes+=i,this},clamp:function(){var t=this.words,r=this.sigBytes;t[r>>>2]&=4294967295<<32-r%4*8,t.length=f.ceil(r/4)},clone:function(){var t=c.clone.call(this);return t.words=this.words.slice(0),t},random:function(t){for(var r=[],n=0;n<t;n+=4)r.push(R());return new u.init(r,t)}}),v=h.enc={},k=v.Hex={stringify:function(t){for(var r=t.words,n=t.sigBytes,e=[],i=0;i<n;i++){var o=r[i>>>2]>>>24-i%4*8&255;e.push((o>>>4).toString(16)),e.push((o&15).toString(16))}return e.join("")},parse:function(t){for(var r=t.length,n=[],e=0;e<r;e+=2)n[e>>>3]|=parseInt(t.substr(e,2),16)<<24-e%8*4;return new u.init(n,r/2)}},B=v.Latin1={stringify:function(t){for(var r=t.words,n=t.sigBytes,e=[],i=0;i<n;i++){var o=r[i>>>2]>>>24-i%4*8&255;e.push(String.fromCharCode(o))}return e.join("")},parse:function(t){for(var r=t.length,n=[],e=0;e<r;e++)n[e>>>2]|=(t.charCodeAt(e)&255)<<24-e%4*8;return new u.init(n,r)}},H=v.Utf8={stringify:function(t){try{return decodeURIComponent(escape(B.stringify(t)))}catch{throw new Error("Malformed UTF-8 data")}},parse:function(t){return B.parse(unescape(encodeURIComponent(t)))}},x=d.BufferedBlockAlgorithm=c.extend({reset:function(){this._data=new u.init,this._nDataBytes=0},_append:function(t){typeof t=="string"&&(t=H.parse(t)),this._data.concat(t),this._nDataBytes+=t.sigBytes},_process:function(t){var r,n=this._data,e=n.words,i=n.sigBytes,o=this.blockSize,g=o*4,a=i/g;t?a=f.ceil(a):a=f.max((a|0)-this._minBufferSize,0);var l=a*o,_=f.min(l*4,i);if(l){for(var w=0;w<l;w+=o)this._doProcessBlock(e,w);r=e.splice(0,l),n.sigBytes-=_}return new u.init(r,_)},clone:function(){var t=c.clone.call(this);return t._data=this._data.clone(),t},_minBufferSize:0});d.Hasher=x.extend({cfg:c.extend(),init:function(t){this.cfg=this.cfg.extend(t),this.reset()},reset:function(){x.reset.call(this),this._doReset()},update:function(t){return this._append(t),this._process(),this},finalize:function(t){t&&this._append(t);var r=this._doFinalize();return r},blockSize:16,_createHelper:function(t){return function(r,n){return new t.init(n).finalize(r)}},_createHmacHelper:function(t){return function(r,n){return new I.HMAC.init(t,n).finalize(r)}}});var I=h.algo={};return h}(Math);return y})}(p)),p.exports}export{P as r};
