import{o as l,R as e,B as n,T as r,ai as a,u as c}from"./rpcWorker-CVTx5FIM.js";import{a as s}from"./ErrorMessageStackTraceDialog-BmncAfrP.js";import{R as i,a as m}from"./Report-Cfa35jgu.js";const k=l(function({model:t}){return e.createElement(n,{message:`${t.error}`,severity:"error",action:e.createElement(e.Fragment,null,e.createElement(r,{title:"Reload track"},e.createElement(a,{"data-testid":"reload_button",onClick:()=>{t.reload()}},e.createElement(i,null))),e.createElement(r,{title:"Show stack trace"},e.createElement(a,{onClick:()=>{c.getSession(t).queueDialog(o=>[s,{onClose:o,error:t.error}])}},e.createElement(m,null))))})});export{k as default};
