import{R as e,c as l,D as c,T as r,L as t,m as u}from"./index-Bm2SqMk3.js";const i=u()({content:{minWidth:800}});function p({open:n,version:o,onClose:s}){const{classes:a}=i();return e.createElement(l.Dialog,{open:n,onClose:s,maxWidth:"xl",title:`JBrowse v${o}`},e.createElement(c,{className:a.content},e.createElement(r,null,"JBrowse is a GMOD project © 2019-2021, The Evolutionary Software Foundation"),e.createElement(r,null,"Here are some resources and documentation. Please report the version number above when asking questions. Thanks!"),e.createElement("ul",null,e.createElement("li",null,e.createElement(t,{href:"https://github.com/GMOD/jbrowse-components/discussions",target:"_blank",rel:"noopener noreferrer"},"Question & answer forum")),e.createElement("li",null,e.createElement(t,{href:"https://github.com/GMOD/jbrowse-components/issues/new/choose",target:"_blank",rel:"noopener noreferrer"},"Report a bug")),e.createElement("li",null,e.createElement(t,{href:"https://jbrowse.org/jb2/docs/user_guide",target:"_blank",rel:"noopener noreferrer"},"User guide")),e.createElement("li",null,e.createElement(t,{href:"https://jbrowse.org/jb2/docs/",target:"_blank",rel:"noopener noreferrer"},"Documentation")))))}export{p as default};
