import{A as g,E as u,u as s,G as p,H as S,I as r}from"./index-Bm2SqMk3.js";import{a as d}from"./aborting-Bc8cczc3.js";function x(o){g(o,u(async()=>{try{const t=s.getContainingView(o);if(!t.initialized)return;const{rpcManager:n}=s.getSession(o),{adapterConfig:e}=o,a=p.createStopToken();o.setSourcesLoading(a);const i=S.getRpcSessionId(o),c=await n.call(i,"MultiWiggleGetSources",{regions:t.staticBlocks.contentBlocks,sessionId:i,adapterConfig:e});r(o)&&o.setSources(c)}catch(t){!d.isAbortException(t)&&r(o)&&(console.error(t),s.getSession(o).notifyError(`${t}`,t))}}))}export{x as getMultiWiggleSourcesAutorun};
