import{x as o,u as i,R as t}from"./index-Bm2SqMk3.js";import{Y as m}from"./YScaleBars-DnW6uLDH.js";import"./util-C94x5Vwy.js";async function g(e,a,n){await o(()=>!!e.stats&&!!e.regionCannotBeRenderedText);const{offsetPx:r}=i.getContainingView(e);return t.createElement(t.Fragment,null,t.createElement("g",null,await n(a)),t.createElement("g",{transform:`translate(${Math.max(-r,0)})`},t.createElement(m,{model:e,orientation:"left",exportSVG:!0})))}export{g as renderSvg};
