const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/BreakendSingleLevelOptionDialog-BmZ-GTMg.js","assets/index-Bm2SqMk3.js","assets/index-B32Lr0K5.css"])))=>i.map(i=>d[i]);
import{u as n,R as a,T as p,L as m,a as u,_ as c}from"./index-Bm2SqMk3.js";import{B as d}from"./BaseCard-BEWjgl8a.js";const g=u.lazy(()=>c(()=>import("./BreakendSingleLevelOptionDialog-BmZ-GTMg.js").then(t=>t.B),__vite__mapDeps([0,1,2]))),v=u.lazy(()=>c(()=>import("./BreakendSingleLevelOptionDialog-BmZ-GTMg.js").then(t=>t.a),__vite__mapDeps([0,1,2])));function E({model:t,feature:e}){const i=n.getSession(t),l={uniqueId:e.uniqueId,refName:e.refName,start:e.start,end:e.end,strand:e.strand},s={uniqueId:`${e.id}-mate`,refName:e.next_ref,start:e.next_pos,end:e.next_pos+1,strand:e.strand};return a.createElement("div",null,a.createElement(p,null,"Launch split view"),a.createElement("ul",null,a.createElement("li",null,l.refName,":",n.toLocale(l.start)," -> ",s.refName,":",n.toLocale(s.start)," ",a.createElement(m,{href:"#",onClick:r=>{r.preventDefault(),i.queueDialog(o=>[g,{handleClose:o,session:i,feature:new n.SimpleFeature({...l,mate:s}),view:t.view,assemblyName:t.view.displayedRegions[0].assemblyName}])}},"(top/bottom)")," ",a.createElement(m,{href:"#",onClick:r=>{r.preventDefault(),i.queueDialog(o=>[v,{handleClose:o,session:i,feature:new n.SimpleFeature({...l,mate:s}),view:t.view,assemblyName:t.view.displayedRegions[0].assemblyName}])}},"(single row)"))))}function f(t){const{model:e,feature:i}=t,l=n.getSession(e),{pluginManager:s}=n.getEnv(l);let r=!1;try{r=!!s.getViewType("BreakpointSplitView")}catch{}return a.createElement(d,{...t,title:"Paired alignments"},r?a.createElement(E,{model:e,feature:i}):null)}export{f as default};
