import{u as a,R as n,F as c,a2 as m,r as u}from"./rpcWorker-CVTx5FIM.js";import{B as p}from"./FeatureDetails-CfRe4vtU.js";const d=u.lazy(()=>import("./BreakendSingleLevelOptionDialog-CY2T9tVv.js").then(function(t){return t.B})),g=u.lazy(()=>import("./BreakendSingleLevelOptionDialog-CY2T9tVv.js").then(function(t){return t.a}));function f({model:t,feature:e}){const i=a.getSession(t),l={uniqueId:e.uniqueId,refName:e.refName,start:e.start,end:e.end,strand:e.strand},s={uniqueId:`${e.id}-mate`,refName:e.next_ref,start:e.next_pos,end:e.next_pos+1,strand:e.strand};return n.createElement("div",null,n.createElement(c,null,"Launch split view"),n.createElement("ul",null,n.createElement("li",null,l.refName,":",a.toLocale(l.start)," -> ",s.refName,":",a.toLocale(s.start)," ",n.createElement(m,{href:"#",onClick:r=>{r.preventDefault(),i.queueDialog(o=>[d,{handleClose:o,session:i,feature:new a.SimpleFeature({...l,mate:s}),view:t.view,assemblyName:t.view.displayedRegions[0].assemblyName}])}},"(top/bottom)")," ",n.createElement(m,{href:"#",onClick:r=>{r.preventDefault(),i.queueDialog(o=>[g,{handleClose:o,session:i,feature:new a.SimpleFeature({...l,mate:s}),view:t.view,assemblyName:t.view.displayedRegions[0].assemblyName}])}},"(single row)"))))}function y(t){const{model:e,feature:i}=t,l=a.getSession(e),{pluginManager:s}=a.getEnv(l);let r=!1;try{r=!!s.getViewType("BreakpointSplitView")}catch{}return n.createElement(p,{...t,title:"Paired alignments"},r?n.createElement(f,{model:e,feature:i}):null)}export{y as default};
