import{B as a}from"./index-P3rx-5SH.js";import{i}from"./rpcWorker-CVTx5FIM.js";class c extends a.BaseAdapter{async getRefNameAliases(){const t=this.getConf("location");if(t.uri===""||t.uri==="/path/to/my/sequence_report.tsv")return[];const r=this.getConf("useUcscNameOverride");return(await i.openLocation(t,this.pluginManager).readFile("utf8")).split(/\n|\r\n|\r/).slice(1).filter(e=>!!e.trim()).map(e=>e.split("	")).map(e=>({refName:e[12],aliases:[e[9],e[6]].filter(s=>!!s),override:r})).filter(e=>!!e.refName)}async freeResources(){}}export{c as default};
