import{o as m,R as e,c as u,D as C,aq as a,ar as E,as as g,e as p,B as c}from"./index-Bm2SqMk3.js";const y=m(function({modalInfo:r={},onClose:n}){const{name:i,dereferenceTypeCount:o,safelyBreakConnection:t}=r;return e.createElement(u.Dialog,{open:!0,maxWidth:"lg",title:`Close connection "${i}"`,onClose:n},e.createElement(C,null,o?e.createElement(e.Fragment,null,e.createElement(a,null,"Closing this connection will close:"),e.createElement(E,null,Object.entries(o).map(([l,s])=>e.createElement(g,{key:l},`${s} ${l}`)))):null,e.createElement(a,null,"Are you sure you want to close this connection?")),e.createElement(p,null,e.createElement(c,{onClick:()=>{n()},color:"primary"},"Cancel"),e.createElement(c,{variant:"contained",onClick:()=>{t==null||t(),n()},color:"primary"},"OK")))});export{y as default};
