import{a as u,R as e,D as m,T as r,v as s,d as p,e as f,B as o}from"./index-Bm2SqMk3.js";import{D as g}from"./Dialog-BaldQZr9.js";const v=({tracks:l,onClose:a})=>{const[n,i]=u.useState(`MultiWiggle ${Date.now()}`),c=l.every(t=>t.type==="QuantitativeTrack");return e.createElement(g,{open:!0,onClose:()=>{a(!1)},title:"Confirm multi-wiggle track create"},e.createElement(m,null,e.createElement(r,null,c?null:"Not every track looks like a QuantitativeTrack. This could have unexpected behavior, confirm if it looks ok.","Listing:"),e.createElement("ul",null,l.map(t=>e.createElement("li",{key:t.trackId},s.readConfObject(t,"name")," - ",t.type))),e.createElement(p,{value:n,onChange:t=>{i(t.target.value)},helperText:"Track name"}),e.createElement(r,null,"Confirm creation of track?")),e.createElement(f,null,e.createElement(o,{onClick:()=>{a(!1)},color:"primary"},"Cancel"),e.createElement(o,{onClick:()=>{a(!0,{name:n})},color:"primary",variant:"contained",autoFocus:!0},"Submit")))};export{v as default};
