import{o,R as e,ao as r}from"./index-Bm2SqMk3.js";import{Y as l}from"./YScaleBars-DnW6uLDH.js";import"./util-C94x5Vwy.js";const s=o(function(a){const{model:t}=a;return e.createElement("div",null,e.createElement(r,{...a}),e.createElement(l,{model:t}))});export{s as default};
