import{g as R}from"./rpcWorker-CVTx5FIM.js";import{r as K}from"./core-Bz6ZLYmm.js";function L(l,w){return w.forEach(function(n){n&&typeof n!="string"&&!Array.isArray(n)&&Object.keys(n).forEach(function(t){if(t!=="default"&&!(t in l)){var c=Object.getOwnPropertyDescriptor(n,t);Object.defineProperty(l,t,c.get?c:{enumerable:!0,get:function(){return n[t]}})}})}),Object.freeze(l)}var A={exports:{}},T=A.exports,x;function G(){return x||(x=1,function(l,w){(function(n,t){l.exports=t(K())})(T,function(n){return function(t){var c=n,B=c.lib,P=B.WordArray,d=B.Hasher,C=c.algo,g=[],S=[];(function(){function i(o){for(var u=t.sqrt(o),h=2;h<=u;h++)if(!(o%h))return!1;return!0}function v(o){return(o-(o|0))*4294967296|0}for(var r=2,e=0;e<64;)i(r)&&(e<8&&(g[e]=v(t.pow(r,1/2))),S[e]=v(t.pow(r,1/3)),e++),r++})();var f=[],j=C.SHA256=d.extend({_doReset:function(){this._hash=new P.init(g.slice(0))},_doProcessBlock:function(i,v){for(var r=this._hash.words,e=r[0],o=r[1],u=r[2],h=r[3],s=r[4],H=r[5],y=r[6],b=r[7],a=0;a<64;a++){if(a<16)f[a]=i[v+a]|0;else{var p=f[a-15],E=(p<<25|p>>>7)^(p<<14|p>>>18)^p>>>3,_=f[a-2],W=(_<<15|_>>>17)^(_<<13|_>>>19)^_>>>10;f[a]=E+f[a-7]+W+f[a-16]}var D=s&H^~s&y,F=e&o^e&u^o&u,$=(e<<30|e>>>2)^(e<<19|e>>>13)^(e<<10|e>>>22),z=(s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25),q=b+z+D+S[a]+f[a],N=$+F;b=y,y=H,H=s,s=h+q|0,h=u,u=o,o=e,e=q+N|0}r[0]=r[0]+e|0,r[1]=r[1]+o|0,r[2]=r[2]+u|0,r[3]=r[3]+h|0,r[4]=r[4]+s|0,r[5]=r[5]+H|0,r[6]=r[6]+y|0,r[7]=r[7]+b|0},_doFinalize:function(){var i=this._data,v=i.words,r=this._nDataBytes*8,e=i.sigBytes*8;return v[e>>>5]|=128<<24-e%32,v[(e+64>>>9<<4)+14]=t.floor(r/4294967296),v[(e+64>>>9<<4)+15]=r,i.sigBytes=v.length*4,this._process(),this._hash},clone:function(){var i=d.clone.call(this);return i._hash=this._hash.clone(),i}});c.SHA256=d._createHelper(j),c.HmacSHA256=d._createHmacHelper(j)}(Math),n.SHA256})}(A)),A.exports}var O=G(),I=R(O),V=L({__proto__:null,default:I},[O]);export{V as s};
