import{o as n,u as r,r as l,R as o}from"./rpcWorker-CVTx5FIM.js";import{B as u}from"./BaseDisplayComponent-hiDF5ISs.js";const d=n(function({model:t}){const s=r.getContainingView(t),e=Math.round(s.dynamicBlocks.totalWidthPx),a=t.height,c=l.useCallback(i=>{t.setRef(i)},[t,e,a]);return o.createElement("canvas",{"data-testid":"cloud-canvas",ref:c,style:{width:e,height:a,position:"absolute"},width:e*2,height:a*2})}),m=n(function({model:t}){return o.createElement(u,{model:t},o.createElement(d,{model:t}))});export{m as default};
